==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/de/download60.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<h3 class="top">Lassen Sie sich nicht über den Tisch ziehen: Das Kleingedruckte (und andere Sachen).</h3>

 Das dvdisaster-Projekt stellt Ihnen diese Software
als <a href="http://www.gnu.org/philosophy/free-sw.de.html">freie Software</a>
unter der <a href="http://dvdisaster.cvs.sourceforge.net/dvdisaster/dvdisaster/COPYING?view=markup">GNU General Public License v2</a>
zur Verfügung.<p>

Das dvdisaster-Projekt möchte außerdem sicherstellen, daß Sie folgendes wissen:
Sie können dvdisaster <a href="download.php">auf diesen Seiten</a> kostenlos und 
ohne die Angabe von persönlichen Daten herunterladen. <p>

Damit es völlig klar ist,
wie das dvdisaster-Projekt seine Software verteilt und was es dabei macht
oder auch nicht tun wird, haben wir die wichtigsten 
Punkte in der nachfolgenden Liste zusammengefaßt:<p>

<b>Internet-Seiten und Downloads</b><p>

Das dvdisaster-Projekt verwendet die folgenden Internet-Domänen
für seine Webseiten und zum Anbieten von Software-Downloads:<p>

dvdisaster.com<br>
dvdisaster.de<br>
dvdisaster.net<br>
dvdisaster.org<p>

Alle Domänen werden auf die selben Seiten unter dvdisaster.net weitergeleitet.<br> 
Außerdem verwendet das dvdisaster-Projekt die Internet-Dienste von
<a href="http://sourceforge.net/projects/dvdisaster">SourceForge.net</a>.<p>

Darüber hinaus betreibt das dvdisaster-Projekt keine weiteren Internetseiten.<p>

<b>Kein Geld oder persönliche Daten erforderlich</b><p>

Das dvdisaster-Projekt erfordert <b>keinen Registrierungsprozeß</b> 
für diese Software. <br>
Es fragt Sie <b>niemals</b> nach persönlichen Daten und
verlangt kein Geld oder Spenden um:

<ul>
<li>diese Webseiten zu nutzen,</li>
<li>die Software herunterzuladen, und</li>
<li>die Software zu benutzen.</li>
</ul><p>

<b>Kryptographische Unterschriften und Prüfsummen</b><p>

Das dvdisaster-Projekt bietet für seine Softwarepakete 
immer <a href="download20.php">kryptographische Unterschriften</a> und
MD5-Prüfsummen an. Beispiele finden Sie auf der
<a href="download.php#download">Seite zum Herunterladen</a>. <p>

Seien Sie mißtrauisch wenn die Unterschriften und Prüfsummen fehlen,
ungültig sind oder nicht mit denen auf den oben genannten Internetseiten
übereinstimmen.<p>

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/de/download60.php <==
<?php
# dvdisaster: German homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>Lassen Sie sich nicht über den Tisch ziehen: Das Kleingedruckte (und andere Sachen).</h3>

 Das dvdisaster-Projekt stellt Ihnen diese Software
als <a href="http://www.gnu.org/philosophy/free-sw.de.html">freie Software</a>
unter der <a href="http://dvdisaster.cvs.sourceforge.net/dvdisaster/dvdisaster/COPYING?view=markup">GNU General Public License v2</a>
zur Verfügung.<p>

Das dvdisaster-Projekt möchte außerdem sicherstellen, daß Sie folgendes wissen:
Sie können dvdisaster <a href="download.php">auf diesen Seiten</a> kostenlos und 
ohne die Angabe von persönlichen Daten herunterladen. <p>

Damit es völlig klar ist,
wie das dvdisaster-Projekt seine Software verteilt und was es dabei macht
oder auch nicht tun wird, haben wir die wichtigsten 
Punkte in der nachfolgenden Liste zusammengefaßt:<p>

<b>Internet-Seiten und Downloads</b><p>

Das dvdisaster-Projekt verwendet die folgenden Internet-Domänen
für seine Webseiten und zum Anbieten von Software-Downloads:<p>

dvdisaster.com<br>
dvdisaster.de<br>
dvdisaster.net<br>
dvdisaster.org<p>

Alle Domänen werden auf die selben Seiten unter dvdisaster.net weitergeleitet.<br> 
Außerdem verwendet das dvdisaster-Projekt die Internet-Dienste von
<a href="http://sourceforge.net/projects/dvdisaster">SourceForge.net</a>.<p>

Darüber hinaus betreibt das dvdisaster-Projekt keine weiteren Internetseiten.<p>

<b>Kein Geld oder persönliche Daten erforderlich</b><p>

Das dvdisaster-Projekt erfordert <b>keinen Registrierungsprozeß</b> 
für diese Software. <br>
Es fragt Sie <b>niemals</b> nach persönlichen Daten und
verlangt kein Geld oder Spenden um:

<ul>
<li>diese Webseiten zu nutzen,</li>
<li>die Software herunterzuladen, und</li>
<li>die Software zu benutzen.</li>
</ul><p>

<b>Kryptographische Unterschriften und Prüfsummen</b><p>

Das dvdisaster-Projekt bietet für seine Softwarepakete 
immer <a href="download20.php">kryptographische Unterschriften</a> und
MD5-Prüfsummen an. Beispiele finden Sie auf der
<a href="download.php#download">Seite zum Herunterladen</a>. <p>

Seien Sie mißtrauisch wenn die Unterschriften und Prüfsummen fehlen,
ungültig sind oder nicht mit denen auf den oben genannten Internetseiten
übereinstimmen.<p>

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
